@@ -23,21 +23,21 @@ import org.apache.mina.core.session.IoSession;
 
 /**
  * The interface for filtering sessions based on various session attributes.
- * 
+ *
  * @author <a href="http://mina.apache.org">Apache MINA Project</a>
- * 
+ *
  */
 
 public interface SessionFilter {
 
     /**
      * Tells whether or not the given session is accepted by this filter.
-     * 
+     *
      * @param session
      *            the session to check
      * @return <code>true</code>, if the given session is accepted by this
      *         filter; <code>false</code>, otherwise.
      */
-    public boolean accept(IoSession session);
+    boolean accept(IoSession session);
 
 }
